Generate a bowerbird data source object for an Australian Antarctic Data Centre data set
Source:R/aadc.R
bb_aadc_source.RdGenerate a bowerbird data source object for an Australian Antarctic Data Centre data set
Usage
bb_aadc_source(metadata_id, eds_id, id_is_metadata_id = FALSE, filter, ...)
bb_aadc_datasource_meta(metadata_id)Arguments
- metadata_id
string: the metadata ID of the data set. Browse the AADC's collection at https://data.aad.gov.au/metadata/records/ to find the relevant
metadata_id- eds_id
integer: (optional) specify one or more
eds_ids if the metadata record has multiple data assets attached to it and you don't want all of them- id_is_metadata_id
logical: if TRUE, use the
metadata_idas the data source ID, otherwise use its DOI- filter
expression: (optional) an expression to use in a
subsetoperation, which will be applied to the datasource metadata data frame. You can view this metadata usingbb_aadc_datasource_meta()- ...
: passed to
bb_source
Value
A tibble containing the data source definition, as would be returned by bb_source
Examples
if (FALSE) { # \dontrun{
## generate the source def for the "AADC-00009" dataset
## (Antarctic Fur Seal Populations on Heard Island, Summer 1987-1988)
src <- bb_aadc_source("AADC-00009")
## download it to a temporary directory
data_dir <- tempfile()
dir.create(data_dir)
res <- bb_get(src, local_file_root = data_dir, verbose = TRUE)
res$files
## generate the CPR data set source, which has two components
## but we want to exclude the logbooks and only retrieve the actual data
src <- bb_aadc_source("AADC-00099", filter = !grepl("logbooks", dataset_name))
} # }